<?php
if (!defined('_PS_VERSION_')) {
    exit;
} 
 

if (!defined('_AGDIR_'))
{
    define('_AGDIR_', dirname(__FILE__));
} 

require_once(_AGDIR_.'/functions.php');

class SAG extends Module
{
    public function __construct()
    {
        $this->bootstrap = true;
        $this->name = 'sag';
        $this->tab = 'marketing';
        $this->version = '3.0.1';
        $this->author = 'Société des Avis Garantis';
        $this->need_instance = 0;
        parent::__construct();
        $this->displayName = $this->l('Société des Avis Garantis');
        $this->description = $this->l('Récupérez les avis de vos clients');
        // Retrocompatibility
        $this->initContext();
    } 
 
    public function installDatabase()
    {
        $query[] = 'DROP TABLE IF EXISTS '._DB_PREFIX_.'sag_average_rating;';
        $query[] = 'DROP TABLE IF EXISTS '._DB_PREFIX_.'sag_reviews;';
        $query[] = 'CREATE TABLE IF NOT EXISTS '._DB_PREFIX_.'sag_reviews (
                      `id_product_avisg` varchar(38) NOT NULL,
                      `product_id` varchar(30) NOT NULL,
                      `ag_reviewer_name` varchar(35) NOT NULL,
                      `rate` varchar(4) NOT NULL,
                      `review` text NOT NULL,
                      `date_time` text NOT NULL,
                      `answer_text` text DEFAULT NULL,
                      `answer_date_time` DATETIME DEFAULT NULL,
                      `id_lang` varchar(3) DEFAULT NULL,
                      PRIMARY KEY (`id_product_avisg`)
                    ) ENGINE=InnoDB DEFAULT CHARSET=utf8;';
        $query[] = 'CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'sag_average_rating` (
                      `id_product_avisg` varchar(38) NOT NULL,
                      `product_id` varchar(30) NOT NULL,
                      `rate` varchar(4) NOT NULL,
                      `percent1` int(11) NOT NULL,
                      `percent2` int(11) NOT NULL,
                      `percent3` int(11) NOT NULL,
                      `percent4` int(11) NOT NULL,
                      `percent5` int(11) NOT NULL,
                      `nb1` int(11) NOT NULL,
                      `nb2` int(11) NOT NULL,
                      `nb3` int(11) NOT NULL,
                      `nb4` int(11) NOT NULL,
                      `nb5` int(11) NOT NULL,
                      `date_time_update` text NOT NULL,
                      `reviews_nb` int(11) NOT NULL,
                      `id_lang` varchar(3) DEFAULT NULL,
                      PRIMARY KEY (`product_id`)
                    ) ENGINE=InnoDB DEFAULT CHARSET=utf8;';

        foreach ($query as $key => $sqlQuery)
        {
            if (!Db::getInstance()->Execute($sqlQuery))
            {
                $this->errors = $this->l('Erreur de création de la table SQL');
                return false;
            } 

        } 

        return true;
    } 
 

    public function uninstallDatabase()
    {
        $query = array();
        $query[] = 'DROP TABLE IF EXISTS '._DB_PREFIX_.'sag_average_rating';
        $query[] = 'DROP TABLE IF EXISTS '._DB_PREFIX_.'sag_reviews';


        foreach ($query as $key => $sqlQuery)
        {
            if (!Db::getInstance()->Execute($sqlQuery)) {
                $this->errors = $this->l('Erreur de suppression de la table SQL');
                return false;
            } 

        } 

        return true;
    } 
 

    public function install()
    {

        if (version_compare(_PS_VERSION_, '1.5', '<')) {    //Installation pour PrestaShop 1.4
            if (!parent::install())
            {
                return false;
            } 
 
            if (!$this->installDatabase()
            || !$this->registerHook('header')
            || !$this->registerHook('footer')
            || !$this->registerHook('leftColumn')
            || !$this->registerHook('productTab')
            || !$this->registerHook('productTabContent')
            || !$this->registerHook('rightColumn')
            || !$this->registerHook('productActions')) {
                return false;
            } 

        } 

        else {        //Installation pour PrestaShop 1.5, 1.6 et 1.7
            if (!$this->installDatabase()
            || !parent::install()
            || !$this->registerHook('displayRightColumnProduct')
            || !$this->registerHook('displayLeftColumn')
            || !$this->registerHook('displayRightColumn')
            || !$this->registerHook('displayHeader')
            || !$this->registerHook('displayFooter')
            || !$this->registerHook('displayProductTab')
            || !$this->registerHook('displayProductButtons')
            || !$this->registerHook('displayProductExtraContent')
            || !$this->registerHook('displayProductTabContent')) {
                $this->errors = array('Erreur d\'installation du module.');
                return false;
            } 

        } 
 
        //On configure par défaut le bloc d'avis iFrame en désactivé (si on a jamais installé le module)
        if (!Configuration::get('sag_widgetPosition'))
        {
            Configuration::updateValue('sag_widgetPosition', "none");
        } 

        //On configure par défaut le widget Javascript en désactivé
        if (!Configuration::get('sag_widgetJavascript'))
        {
            Configuration::updateValue('sag_widgetJavascript', false);
        } 

        //On configure par défaut le lien Footer en désactivé
        if (!Configuration::get('sag_footerLink')) {
            Configuration::updateValue('sag_footerLink', false);
        } 

        return true;
    } 
 
    public function uninstall()
    {
        if ( !parent::uninstall() ||  !$this->uninstallDatabase()) {
            $this->errors = $this->l('La désinstallation a échouée');
            return false;
        } 

        return true;
    } 
    
    // Retrocompatibility 1.4/1.5
    private function initContext()
    {
      if (class_exists('Context'))
        $this->context = Context::getContext();
      else
      {
        global $smarty, $cookie;
        $this->context = new StdClass();
        $this->context->smarty = $smarty;
        $this->context->cookie = $cookie;
      }
    }
 
    public function displayIframeWidget()
    {
        $shopID = getShopId();
        $url=getCertificateUrl();
        $this->context->smarty->assign(array(
            'url_ag' => $url,
            'shopID' => $shopID
        ));
        return $this->display(__FILE__ , 'views/templates/front/displayIframeWidget.tpl');
    } 
 
    public function hookdisplayLeftColumn()
    {
        if (Configuration::get('sag_widgetPosition')=="left") {
            return $this->displayIframeWidget();
        } 

        else {
            return false;
        } 

    } 
 
    public function hookdisplayFooter()
    {
        //On récupère les données de configuration du widget et du lien de vérification
        $widgetFooter = (Configuration::get('sag_widgetPosition')=="footer") ? 1 : 0 ;
        $footerLink = Configuration::get('sag_footerLink');
        $this->smarty->assign(array(
            'widgetFooter' => $widgetFooter,
            'footerLink' => $footerLink,
        ));
        //Si on doit afficher l'un ou l'autre il faut récupérer certaines variables
        if ($widgetFooter or $footerLink) {
            $url=getCertificateUrl();
            $this->smarty->assign(array(
                'url_sag' => $url,
            ));
            //Si on doit afficher le widget iframe dans le footer
            if ($widgetFooter) {
                $shopID = getShopId();
                $this->context->smarty->assign(array('shopID' => $shopID));
            } 

            //Si on doit afficher le lien dans le footer
            if ($footerLink) {
            $this->smarty->assign(array('modules_dir' => _MODULE_DIR_));
            } 

        } 

        return $this->display(__FILE__ , 'views/templates/front/displayFooter.tpl');
    } 
 
    public function hookdisplayRightColumn()
    {
        if (Configuration::get('sag_widgetPosition')=="right")
        {
            return $this->displayIframeWidget();
        } 

        else {
            return false;
        } 

    } 
 
    //Widget javascript
    public function hookdisplayHeader()
    {
        if (version_compare(_PS_VERSION_, '1.5', '<'))
        {
            $output = '<script type="text/javascript" src="'._MODULE_DIR_.$this->name.'/views/js/sag.js"></script>
                <link type="text/css" rel="stylesheet" href="'._MODULE_DIR_.$this->name.'/views/css/style.css" />';
        } 

        else {
            $this->context->controller->addCSS(($this->_path).'views/css/style.css', 'all');
            //$this->context->controller->addjQuery('2.0.0');
            $this->context->controller->addJS(($this->_path).'views/js/sag.js', 'all');
        } 
 
        if (Configuration::get('sag_widgetJavascript'))
        {
            $shopID = getShopId();
            $url=getCertificateUrl();

            //WHAT IS IT?
            if (filter_var($url, FILTER_VALIDATE_URL))
            {
            } 
            else $url=Tools::substr($url, 0, 10);

            $this->context->smarty->assign(array(
                'url_ag' => $url,
                'shopID' => $shopID,
                'displayJSWidget' => 1
            ));
        } 

        else {
            $this->smarty->assign(array(
                'displayJSWidget' => 0
            ));
        } 

        return (isset($output) ? $output : null) . $this->display(__FILE__ , 'views/templates/front/displayHeader.tpl');
    } 

    //Presta <1.5
    public function hookHeader()
    {
        return $this->hookdisplayHeader();
    } 
 
    public function hookFooter()
    {
        return $this->hookdisplayFooter();
    } 
 
    public function hookProductActions()
    {
        return $this->hookdisplayRightColumnProduct();
    } 
 
    public function hookRightColumn()
    {
        return $this->hookdisplayRightColumn();
    } 
 
    public function hookLeftColumn()
    {
        return $this->hookdisplayLeftColumn();
    } 
 
    public function hookProductTab()
    {
        return $this->hookdisplayProductTab();
    } 
 
    public function hookProductTabContent()
    {
        return $this->hookdisplayProductTabContent();
    } 
 
    public function hookdisplayProductTab()
    {
        //Si la version est inférieure à 1.7.0 on utilise le product tab sinon non
        if (version_compare(_PS_VERSION_, '1.7.0', '<'))
        {
            $productID = (int)(Tools::getValue('id_product'));
            $sqlQuery = "SELECT count(*) FROM "._DB_PREFIX_."sag_reviews WHERE product_id='$productID'";
            $nb= Db::getInstance()->getValue($sqlQuery);
            if ($nb < 1) return "";
            $this->smarty->assign(array('nbOfReviews' => 5));
            return $this->display(__FILE__ , 'views/templates/front/displayProductTab.tpl');
        } 

        else {
            return false;
        } 

    } 

     public function hookdisplayProductTabContent()
     {
        $productID = (int)(Tools::getValue('id_product'));

        //Récupération du nombre d'avis
        $sqlQuery = "SELECT count(*) FROM "._DB_PREFIX_."sag_reviews WHERE product_id='$productID'";
        $nb= Db::getInstance()->getValue($sqlQuery);
        $sqlQuery = "SELECT * FROM "._DB_PREFIX_."sag_average_rating WHERE product_id='$productID'";
        $ratingValues= Db::getInstance()->getRow($sqlQuery);
        $rating=$ratingValues['rate'];
        if ($nb < 1)
        {
            return ""; //Si Aucun avis, on retourne vide
        } 
 
        $nbMaxReviews=10;
        $sqlQuery = "SELECT * FROM "._DB_PREFIX_."sag_reviews WHERE product_id='$productID' ORDER BY date_time DESC LIMIT $nbMaxReviews";
        $reviews = Db::getInstance()->ExecuteS($sqlQuery);

        //Récupération de l'objet produit
        if (!isset($params['product']))
        {
            if (!$id_product = Tools::getValue('id_product'))
            {
                return $this->l('Missing product object. Set new object mode from the back office Configuration');
            } 
 
            //Fix context undefined bug in 1.4, maybe PS_LANG_DEFAULT works in 1.5 1.6... etc but not tested so we keep old code
            if (version_compare(_PS_VERSION_, '1.5', '<'))
            {
                $product = new Product($id_product, false, Configuration::get('PS_LANG_DEFAULT'));
            } 

            else {
                $product = new Product($id_product, false, $this->context->language->id);
            } 

            $params['product'] = $product;
        } 
 
        $url=getCertificateUrl();
        $this->smarty->assign(array(
            'reviews' => $reviews,
            'ratingValues' => $ratingValues,
            'nbOfReviews' => $nb,
            'reviewsAverage' => round($rating,1),
            'certificateUrl'=> $url,
            'showStructured'=> Configuration::get('sag_showStructured'),
            'productSAG'=> $params['product']
        ));
        if (version_compare(_PS_VERSION_, '1.7.0', '<'))
        {
            return $this->display(__FILE__, 'views/templates/front/displayProductTabContent.tpl');
        } 

        else {
            return $this->display(__FILE__, 'views/templates/front/displayProductTabContent16.tpl');
        } 

    } 
 
    //New product tab and tab content for PS1.7
    public function hookDisplayProductExtraContent($params)
    {
        $productID = (int)(Tools::getValue('id_product'));

        //Récupération du nombre d'avis
        $sqlQuery = "SELECT count(*) FROM "._DB_PREFIX_."sag_reviews WHERE product_id='$productID'";
        $nb= Db::getInstance()->getValue($sqlQuery);
        $sqlQuery = "SELECT * FROM "._DB_PREFIX_."sag_average_rating WHERE product_id='$productID'";
        $ratingValues= Db::getInstance()->getRow($sqlQuery);
        $rating=$ratingValues['rate'];
        $array = array();
        if ($nb > 0)
        {
            $nbMaxReviews=10;
            $sqlQuery = "SELECT * FROM "._DB_PREFIX_."sag_reviews WHERE product_id='$productID' ORDER BY date_time DESC LIMIT $nbMaxReviews";
            $reviews = Db::getInstance()->ExecuteS($sqlQuery);

            //Récupération de l'objet produit
            if (!isset($params['product']))
            {
                if (!$id_product = Tools::getValue('id_product'))
                {
                    return $this->l('Missing product object. Set new object mode from the back office Configuration');
                } 

                $product = new Product($id_product, false, $this->context->language->id);
                $params['product'] = $product;
            } 
 
            $url=getCertificateUrl();
             $this->smarty->assign(array(
                'reviews' => $reviews,
                'ratingValues' => $ratingValues,
                'nbOfReviews' => $nb,
                'reviewsAverage' => round($rating,1),
                'certificateUrl'=> $url,
                'showStructured'=> Configuration::get('sag_showStructured'),
                'product'=> $params['product'],
                'modules_dir' => _MODULE_DIR_,
            ));
            $output = ($this->display(__FILE__ , 'views/templates/front/displayProductTabContent.tpl'));
            $productExtraContent = new PrestaShop\PrestaShop\Core\Product\ProductExtraContent();
            $array[] = $productExtraContent->setTitle($nb . ' avis')->setContent($output);
        } 

        return $array;
    } 

    //new rightcolumnproduct for ps 1.7
    public function hookDisplayProductButtons($params)
    {
        //Seulement si on est en 1.7
        if (version_compare(_PS_VERSION_,'1.7','>')) {
            $productID = (int)(Tools::getValue('id_product'));
            $sqlQuery = "SELECT count(*) FROM "._DB_PREFIX_."sag_reviews WHERE product_id='$productID'";
            $nb= Db::getInstance()->getValue($sqlQuery);
            $sqlQuery = "SELECT rate FROM "._DB_PREFIX_."sag_average_rating WHERE product_id='$productID'";
            $rating= Db::getInstance()->getValue($sqlQuery);
            if ($nb < 1) {
                return ""; //Si Aucun avis, on retourne vide
            } 

            $this->smarty->assign(array('nbReviews' => $nb,'reviewRate' =>  $rating));
            return $this->display(__FILE__ , 'views/templates/front/displayRightColumnProduct.tpl');
        } 

    } 
 
    public function hookdisplayRightColumnProduct()
    {
        $productID = (int)(Tools::getValue('id_product'));
        $sqlQuery = "SELECT count(*) FROM "._DB_PREFIX_."sag_reviews WHERE product_id='$productID'";
        $nb= Db::getInstance()->getValue($sqlQuery);
        $sqlQuery = "SELECT rate FROM "._DB_PREFIX_."sag_average_rating WHERE product_id='$productID'";
        $rating= Db::getInstance()->getValue($sqlQuery);
        if ($nb < 1)
        {
            return ""; //Si Aucun avis, on retourne vide
        } 

        $this->smarty->assign(array('nbReviews' => $nb,'reviewRate' =>  $rating));
        return $this->display(__FILE__ , 'views/templates/front/displayRightColumnProduct.tpl');
    } 
 
    public function getContent()
    {
        $error=false;
        $output = null;

        //Si on a soumis le formulaire de création de certificat
        if (Tools::getValue('createCertificate')) {
            if (!Tools::getValue('cgv_1')) { //Si on a pas validé les CGV on renvoie une erreur
                $displayError = 'Vous devez accepter les CGV pour continuer.';
                $output .= $this->displayError( $this->l($displayError));
                $error = true;
            } 

            elseif (!(filter_var(Tools::getValue('sag_accountMail'), FILTER_VALIDATE_EMAIL))) {
                $displayError = 'Vous devez entrer une adresse email valide pour continuer.';
                $output .= $this->displayError( $this->l($displayError));
                $error = true;
            } 

            else {
                $datas = createCertificate(
                    Tools::getValue('api_siteName'),
                    Tools::getValue('sag_accountAddress'),
                    Tools::getValue('sag_accountAddress2'),
                    Tools::getValue('sag_accountCP'),
                    Tools::getValue('sag_accountCity'),
                    Tools::getValue('sag_accountMail'),
                    Configuration::get('PS_LOGO')
                );
                if ($datas["apiKey"]) { //Si on a une réponse contenant une clé d'api
                    Configuration::updateValue('sag_apiKey', $datas["apiKey"]);    //On enregistre l'apiKey
                    Configuration::updateValue('sag_accountMail', Tools::getValue('sag_accountMail')); //On enregistre le mail du compte
                    Configuration::updateValue('sag_password', $datas["password"]); //Et le mot de passe

                    //Et on active tous les widgets
                    Configuration::updateValue('sag_widgetPosition', "left");
                    Configuration::updateValue('sag_widgetJavascript', true);
                    Configuration::updateValue('sag_footerLink', true);
                    //On regénère l'url du certificat + sauvegarde
                    $urlCertificat = setCertificateUrlFromAPI();
                    $output .= $this->displayConfirmation( $this->l('Certificat créé avec succès : <a href=' . $urlCertificat . ' target="_blank">' . $urlCertificat . '</a><br>
                    Widgets activés'));
                } 

                else {
                    //Si on a déjà un certificat
                    if ($datas["error"] == "Domain already registered") {
                        if (Configuration::get('sag_apiKey')) { //Et qu'on a déjà une clé en mémoire
                            $sag = Configuration::get('sag_apiKey'); //On remet l'ancienne.
                            $output .= $this->displayConfirmation( "Il existe déjà un certificat pour ce site, rétablissement de l'ancienne clé d'API : " . $sag);
                        } 

                        else {
                            $output .= $this->displayConfirmation( $this->l('Ce site est déjà enregistré chez la Société des Avis Garantis<br>
                            Pour récupérer votre clé d\'API, <a href=https://www.societe-des-avis-garantis.fr/configuration/prestashop/ target="_blank">cliquez ici</a>.<br>
                            '));
                        } 

                    } 

                    //Si l'email exist déjà
                    elseif (array_key_exists("existing_user_login", $datas["error"]) or array_key_exists("existing_user_email", $datas["error"])) {
                        $displayError = 'Cette adresse email est déjà utilisée pour un autre compte.<br>
                        Merci d\'entrer une autre adresse email.';
                        $output .= $this->displayError( $this->l($displayError));
                    } 

                    //Sinon on a une erreur mais on ne sait pas pourquoi
                    else {
                        $output .= $this->displayConfirmation( $this->l('Pour finaliser votre inscription :
                        <strong><a href=https://www.societe-des-avis-garantis.fr/wp-login.php?action=register target="_blank">Cliquez ici</a></strong>
                        '));
                        Tools::redirect('https://www.societe-des-avis-garantis.fr/wp-login.php?action=register');
                        exit();
                    } 

                    $error = true;
                } 

            } 

        } 

        elseif (Tools::getValue('mainConfig')) { //Sinon si on a soumis le formulaire de configuration principal

            //On récupère les données passéees
            $sag = strval(Tools::getValue('sag_apiKey'));
            $sag_afterDays = strval(Tools::getValue('sag_afterDays'));
            $sag_showStructured = (Tools::getValue('sag_showStructured'));
            $sag_widgetPosition = strval(Tools::getValue('sag_widgetPosition'));
            $sag_widgetJavascript = (Tools::getValue('sag_widgetJavascript'));
            $sag_footerLink = (Tools::getValue('sag_footerLink'));
            $sag_exeptStatus = (Tools::getValue('sag_exeptStatus'));
            $sag_exeptStatusString = "";
            if ($sag_exeptStatus) {
                $sag_exeptStatusString = implode(",", $sag_exeptStatus);
            } 

            Configuration::updateValue('sag_apiKey', $sag);
            Configuration::updateValue('sag_exeptStatus', $sag_exeptStatusString);
            Configuration::updateValue('sag_afterDays', $sag_afterDays);
            Configuration::updateValue('sag_widgetPosition', $sag_widgetPosition);
            Configuration::updateValue('sag_widgetJavascript', $sag_widgetJavascript);
            Configuration::updateValue('sag_footerLink', $sag_footerLink);
            Configuration::updateValue('sag_showStructured', $sag_showStructured);
            //On regénère l'url du certificat + sauvegarde
            setCertificateUrlFromAPI();
            $output .= $this->displayConfirmation($this->l('Mis à jour avec succès'));
        } 

        elseif (Tools::getValue('alreadyUser')) { //Si on a soumis le formulaire "déjà inscrit"
            $sag = strval(Tools::getValue('sag_apiKey'));
            //On vérifie qu'on a une api KEY
            if (!$sag) {
                $displayError = 'Vous devez entrer une clé d\'api pour continuer.';
                $output .= $this->displayError($this->l($displayError));
            } 

            else { //Si c'est bon, on active tous les widgets
                $sag_widgetPosition ="left";
                $sag_footerLink = true;
                $sag_widgetJavascript = true;
                $output .= $this->displayConfirmation($this->l('Module configuré avec succès, widgets activés'));
                Configuration::updateValue('sag_apiKey', $sag);
                Configuration::updateValue('sag_widgetPosition', $sag_widgetPosition);
                Configuration::updateValue('sag_widgetJavascript', $sag_widgetJavascript);
                Configuration::updateValue('sag_footerLink', $sag_footerLink);
                Configuration::updateValue('sag_accountMail', ""); //On efface le mail du compte
                Configuration::updateValue('sag_password', ""); //Et le mot de passe
                //On regénère l'url du certificat + sauvegarde
                setCertificateUrlFromAPI();
            } 

        } 

        $output .= '
        <h2>'.$this->displayName.'</h2>';

        //createApiKey Form

        //Generate apiDesc (Permet d'afficher les identifiants du compte sous l'apiKey s'il y en a)
        $apiDesc = "";
        if (Configuration::get('sag_accountMail')) {     //Si on a un mail de compte, on a généré l'apiKey automatiquement
            $apiDesc .= "<strong>Gestion des avis : <a href='https://www.societe-des-avis-garantis.fr/wp-login.php' target='_blank'>Cliquez ici</a></strong><br>";
            $apiDesc .= "Identifiant : " . Configuration::get('sag_accountMail') . "<br>";
            $apiDesc .= "Mot de passe : " . Configuration::get('sag_password') ;
        } 

        Configuration::updateValue('sag_apiDesc', $apiDesc);


        //Some necessary css
        $css = "
        <style>
        .sagExeptStatus{
            height: 150px;
            padding: 0px 5px;
        } 

        </style>";
        //Fix double clic on form error
        $pureJsHack = '
        <script>
            //Si on soumet le formulaire
            var createCertificate = document.querySelector("input[name=\'createCertificate\']");
            createCertificate && createCertificate.addEventListener(\'click\', function() {
                var span = document.createElement(\'span\');
                    span.innerHTML = \'Veuillez patienter...\';
                    span.className = \'wait\';

                createCertificate.parentNode.insertBefore(span, createCertificate);
                //On le cache
                createCertificate.style.display = \'none\';
            } 
);
        </script>';

        if (version_compare(_PS_VERSION_, '1.5', '<')) { //Si presta 1.4
            return $output.$this->displayForm14() . $pureJsHack . $css;
        } 

        else {
            return $output . $this->displayForm() . $pureJsHack . $css;
        } 

    } 
 
    public function displayForm()
    {
        // Get default Language
        $default_lang = (int)Configuration::get('PS_LANG_DEFAULT');

        //Get order state list
        $sqlQuery = "SELECT * FROM "._DB_PREFIX_."order_state_lang where id_lang=$default_lang";
        $orderStates = Db::getInstance()->ExecuteS($sqlQuery);
        //Format datas
        foreach ($orderStates as $orderState) {
            $stateList[] = array("key" => $orderState['id_order_state'], "name"=>$orderState['name']);
        } 
 
        // Init Fields form array
        $installedForm['form'] = array(
            'legend' => array(
                'title' => $this->l('Settings'),
            ),
            'input' => array(
                array(
                    'type' => 'text',
                    'label' => $this->l('Clé d\'api'),
                    'name' => 'sag_apiKey',
                    'size' => 30,
                    'desc' => Configuration::get('sag_apiDesc'),
                    'required' => false
                ),
                array(
                    'type' => 'select',
                    'label' => $this->l('Statuts à exclure'),
                    'class' => "sagExeptStatus",
                    'name' => 'sag_exeptStatus[]',
                    'desc' => 'Sélectionnez les statuts de commandes auxquels il ne faut pas demander d\'avis<br>
                    (CTRL pour en sélectionner plusieurs)',
                    'multiple' => true,
                    'options' => array(
                        'query' => $stateList,
                        'id' => 'key',
                        'name' => 'name'
                    )
                ),
                array(
                    'type' => 'text',
                    'label' => $this->l('Délai d\'envoi du mail'),
                    'name' => 'sag_afterDays',
                    'size' => 30,
                    'desc' => $this->l('Nombre de jours avant d\'envoyer la demande d\'avis après le passage de la commande (10 si vide)'),
                    'required' => false
                ),

                //Choix de l'emplacement du widget iFrame
                array(
                  'type'      => 'radio',                               // This is an <input type="checkbox"> tag.
                  'label'     => $this->l('Widget iFrame'),        // The <label> for this <input> tag.
                  'desc'      => $this->l('Affichage gauche / droite possible seulement si votre thème possède des colonnes'),   // A help text, displayed right next to the <input> tag.
                  'name'      => 'sag_widgetPosition',                              // The content of the 'id' attribute of the <input> tag.
                  'required'  => true,                                  // If set to true, this option must be set.
                'class'     => 't',
                 'is_bool'   => false,                                  // If set to true, this means you want to display a yes/no or true/false option.
                  'values'    => array(                                 // $values contains the data itself.
                    array(
                      'id'    => 'active_on',                           // The content of the 'id' attribute of the <input> tag, and of the 'for' attribute for the <label> tag.
                      'value' => "left",                                     // The content of the 'value' attribute of the <input> tag.
                      'label' => $this->l('Gauche')                    // The <label> for this radio button.
                    ),
                    array(
                      'id'    => 'active_off',
                      'value' => "right",
                      'label' => $this->l('Droite')
                    ),
                    array(
                      'id'    => 'active_footer',
                      'value' => "footer",
                      'label' => $this->l('Footer')
                    ),
                    array(
                      'id'    => 'active_none',
                      'value' => "none",
                      'label' => $this->l('Désactiver')
                    )
                  ),
                ),
                //Choix de l'emplacement du widget Javascript
                array(
                  'type'      => 'radio',                               // This is an <input type="checkbox"> tag.
                  'label'     => $this->l('Widget Javascript'),        // The <label> for this <input> tag.
                  'desc'      => 'Pour choisir le widget et définir sa position,
                                           <a href="https://www.societe-des-avis-garantis.fr/configuration/widgets/" target="_blank">cliquez ici</a>',   // A help text, displayed right next to the <input> tag.
                  'name'      => 'sag_widgetJavascript',                              // The content of the 'id' attribute of the <input> tag.
                  'required'  => true,                                  // If set to true, this option must be set.
                'class'     => 't',
                 'is_bool'   => false,                                  // If set to true, this means you want to display a yes/no or true/false option.
                  'values'    => array(                                 // $values contains the data itself.
                    array(
                      'id'    => 'wjs_on',                           // The content of the 'id' attribute of the <input> tag, and of the 'for' attribute for the <label> tag.
                      'value' => true,                                     // The content of the 'value' attribute of the <input> tag.
                      'label' => $this->l('Activer')                    // The <label> for this radio button.
                    ),
                    array(
                      'id'    => 'wjs_off',
                      'value' => false,
                      'label' => $this->l('Désactiver')
                    )
                  ),
                ),

                //Choix de si on affiche ou pas le lien de verif du certificat dans le footer
                array(
                  'type'      => 'radio',
                  'label'     => $this->l('Lien de vérification'),
                  'desc'      => 'Affiche un lien de vérification dans le footer pointant vers votre certificat. <br>(Important pour votre référencement)',
                  'name'      => 'sag_footerLink',
                  'required'  => true,
                'class'     => 't',
                 'is_bool'   => true,                                  // If set to true, this means you want to display a yes/no or true/false option.
                  'values'    => array(                                 // $values contains the data itself.
                    array(
                      'id'    => 'showFooterLink_on',                           // The content of the 'id' attribute of the <input> tag, and of the 'for' attribute for the <label> tag.
                      'value' => 1,                                     // The content of the 'value' attribute of the <input> tag.
                      'label' => $this->l('Oui')                    // The <label> for this radio button.
                    ),
                    array(
                      'id'    => 'showFooterLink_off',
                      'value' => 0,
                      'label' => $this->l('Non')
                    )
                  ),
                ),

                //Choix de si on déclare les données structurées "Product" et "Product name" ou pas sur les fiches produit
                array(
                  'type'      => 'radio',                               // This is an <input type="checkbox"> tag.
                  'label'     => $this->l('Forcer les données structurées'),        // The <label> for this <input> tag.
                  'desc'      => 'A activer seulement si votre thème ne les implémente pas.<br><a href=https://search.google.com/structured-data/testing-tool/u/0/ target="_blank">Cliquez ici pour tester les données structurées de vos pages produit</a>',   // A help text, displayed right next to the <input> tag.
                  'name'      => 'sag_showStructured',                              // The content of the 'id' attribute of the <input> tag.
                  'required'  => true,                                  // If set to true, this option must be set.
                'class'     => 't',
                 'is_bool'   => true,                                  // If set to true, this means you want to display a yes/no or true/false option.
                  'values'    => array(                                 // $values contains the data itself.
                    array(
                      'id'    => 'showStructured_on',                           // The content of the 'id' attribute of the <input> tag, and of the 'for' attribute for the <label> tag.
                      'value' => 1,                                     // The content of the 'value' attribute of the <input> tag.
                      'label' => $this->l('Oui')                    // The <label> for this radio button.
                    ),
                    array(
                      'id'    => 'showStructured_off',
                      'value' => 0,
                      'label' => $this->l('Non')
                    )
                  ),
                ),
            ),
            'submit' => array(
                'title' => $this->l('Save'),
                'class' => 'button',
                'name' => 'mainConfig'
            )
        );


        //Formulaire d'inscription
        $firstInstall['form'] = array (
            'legend' => array ('title'=>"Première installation ?"),
            'input' => array(
                    array(
                        'type' => 'text',
                        'label' => $this->l('Nom du site'),
                        'name' => 'api_siteName',
                        'size' => 30,
                        'desc' => "Apparaîtra sur votre certificat",
                        'required' => false
                    ),
                    array(
                        'type' => 'hidden',
                        'label' => $this->l('Adresse'),
                        'name' => 'sag_accountAddress',
                        'size' => 30,
                        'desc' => "Apparaîtra sur votre certificat",
                        'required' => false
                    ),
                    array(
                        'type' => 'hidden',
                        'label' => $this->l('Complément'),
                        'name' => 'sag_accountAddress2',
                        'size' => 30,
                        'desc' => "Apparaîtra sur votre certificat",
                        'required' => false
                    ),
                    array(
                        'type' => 'hidden',
                        'label' => $this->l('Code postal'),
                        'name' => 'sag_accountCP',
                        'size' => 30,
                        'desc' => "Apparaîtra sur votre certificat",
                        'required' => false
                    ),
                    array(
                        'type' => 'hidden',
                        'label' => $this->l('Ville'),
                        'name' => 'sag_accountCity',
                        'size' => 30,
                        'desc' => "Apparaîtra sur votre certificat",
                        'required' => false
                    ),
                    array(
                        'type' => 'text',
                        'label' => $this->l('Votre email'),
                        'name' => 'sag_accountMail',
                        'size' => 30,
                        'desc' => "Sera utilisé comme identifiant de votre compte Société des Avis Garantis",
                        'required' => false
                    ),

                    array(
                      'type'    => 'checkbox',                         // This is an <input type="checkbox"> tag.
                      'label'   => $this->l(''),                // The <label> for this <input> tag.
                      'name'    => 'cgv',                          // The content of the 'id' attribute of the <input> tag.
                      'values'  => array(
                        'query' => array(
                                      array(
                                        'id_option' => 1,                 // The value of the 'value' attribute of the <option> tag.
                                        'name' => 'J\'accepte les <a href=https://www.societe-des-avis-garantis.fr/cgv/ target="_blank">CGV de la Société Avis Garantis</a>'              // The value of the text content of the  <option> tag.
                                      ),
                                    ),                           // $options contains the data itself.
                        'id'    => 'id_option',                        // The value of the 'id' key must be the same as the key for 'value' attribute of the <option> tag in each $options sub-array.
                        'name'  => 'name'                              // The value of the 'name' key must be the same as the key for the text content of the <option> tag in each $options sub-array.
                      ),
                    ),
            ),
            'submit' => array(
                'title' => $this->l('Valider'),
                'name' => "createCertificate",
                'class' => 'button'
            )
        );

        //Déjà inscrit ?
        $alreadyInstalled['form'] = array (
            'legend' => array ('title'=>"Déjà inscrit ?"),
            'input' => array(
                array(
                    'type' => 'text',
                    'label' => $this->l('Clé d\'api'),
                    'name' => 'sag_apiKey',
                    'size' => 30,
                    'desc' => "Votre clé se trouve sur votre compte Société des Avis Garantis: <a href=https://www.societe-des-avis-garantis.fr/configuration/prestashop/ target='_blank'>Cliquez ici</a>",
                    'required' => false
                ),
            ),
            'submit' => array(
                'title' => $this->l('Save'),
                'name' => "alreadyUser",
                'class' => 'button'
            )
        );

        $fields_form = array();
        if (!Configuration::get('sag_apiKey')) {
            array_unshift ($fields_form, $alreadyInstalled);
            array_unshift ($fields_form, $firstInstall);
        } 

        else {
            array_unshift ($fields_form, $installedForm);
        } 

        $helper = new HelperForm();

        // Module, token and currentIndex
        $helper->module = $this;
        $helper->name_controller = $this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;

        // Language
        $helper->default_form_language = $default_lang;
        $helper->allow_employee_form_lang = $default_lang;

        // Title and toolbar
        $helper->title = $this->displayName;
        $helper->show_toolbar = false;        // false -> remove toolbar
        $helper->toolbar_scroll = true;      // yes - > Toolbar is always visible on the top of the screen.
        $helper->submit_action = 'submit'.$this->name;
        $helper->toolbar_btn = array(
            'save' =>
            array(
                'desc' => $this->l('Save'),
                'href' => AdminController::$currentIndex.'&configure='.$this->name.'&save'.$this->name.
                '&token='.Tools::getAdminTokenLite('AdminModules'),
            ),
            'back' => array(
                'href' => AdminController::$currentIndex.'&token='.Tools::getAdminTokenLite('AdminModules'),
                'desc' => $this->l('Back to list')
            )
        );

        // Load current value
        $helper->fields_value['sag_exeptStatus[]'] = explode(",", Configuration::get('sag_exeptStatus'));

        $helper->fields_value['sag_apiKey'] = Configuration::get('sag_apiKey');
        $helper->fields_value['sag_afterDays'] = Configuration::get('sag_afterDays');
        $helper->fields_value['sag_widgetPosition'] = Configuration::get('sag_widgetPosition');
        $helper->fields_value['sag_widgetJavascript'] = Configuration::get('sag_widgetJavascript');
        $helper->fields_value['sag_footerLink'] = Configuration::get('sag_footerLink');
        $helper->fields_value['sag_showStructured'] = Configuration::get('sag_showStructured');
        $helper->fields_value['sag_accountMail'] = Configuration::get('PS_SHOP_EMAIL');
        $helper->fields_value['api_siteName'] = Configuration::get('PS_SHOP_NAME');
        $helper->fields_value['sag_accountAddress'] = Configuration::get('PS_SHOP_ADDR1');
        $helper->fields_value['sag_accountAddress2'] = Configuration::get('PS_SHOP_ADDR2');
        $helper->fields_value['sag_accountCP'] = Configuration::get('PS_SHOP_CODE');
        $helper->fields_value['sag_accountCity'] = Configuration::get('PS_SHOP_CITY');
        $helper->fields_value['sag_password'] = Configuration::get('sag_password');

        return $helper->generateForm($fields_form);
    } 
 
    public function displayForm14()
    {
        // Get default Language
        $default_lang = (int)Configuration::get('PS_LANG_DEFAULT');

        $output = '';

        $output .= '<form action="'.Tools::safeOutput($_SERVER['REQUEST_URI']).'" method="post" enctype="multipart/form-data">';

        $mainForm = '
        <fieldset>
            <legend>'.$this->l('Configuration SAG').'</legend>
            <label>API KEY </label>
            <div class="margin-form">
                <input type="text" name="sag_apiKey" id="sag_apiKey" value="' . Configuration::get('sag_apiKey') . '" class="" size="30">
                <sup>*</sup>
            </div>
<!-- NON PRIS EN CHARGE EN 1.4 IL FAUT ADAPTER LAPI
            <label>Statuts à exclure </label>
            <div class="margin-form">
                <input type="text" name="sag_exeptStatus" id="sag_exeptStatus" value="'. Configuration::get('sag_exeptStatus') . '" class="" size="30">
                <p class="preference_description">
                Ne pas envoyer la demande d\'avis aux commandes portant le statut suivant (ex:1,2,3)
                </p>
            </div>
-->
            <label>Délai d\'envoi du mail </label>
            <div class="margin-form">
                <input type="text" name="sag_afterDays" id="sag_afterDays" value="' . Configuration::get('sag_afterDays') . '" class="" size="30">
                <p class="preference_description">
                Nombre de jours avant d\'envoyer la demande d\'avis après le passage de la commande (10 si vide)
                </p>
            </div>

            <label>Widget iFrame </label>
            <div class="margin-form">
                <input type="radio" name="sag_widgetPosition" id="active_on" value="left" '. ((Configuration::get('sag_widgetPosition')=="left") ? 'checked="checked"' : '') .'>
                <label class="t" for="active_on">
                Gauche
                </label>
                <input type="radio" name="sag_widgetPosition" id="active_off" value="right" '. ((Configuration::get('sag_widgetPosition')=="right") ? 'checked="checked"' : '') .'>
                <label class="t" for="active_off">
                Droite
                </label>
                <input type="radio" name="sag_widgetPosition" id="active_none" value="none" '. ((Configuration::get('sag_widgetPosition')!="right" and Configuration::get('sag_widgetPosition')!="left" ) ? 'checked="checked"' : '') .'>
                <label class="t" for="active_none">
                Désactiver
                </label>
                <p class="preference_description">
                Seulement si votre thème possède des colonnes
                </p>
            </div>

            <label>Widget Javascript </label>
            <div class="margin-form">
                <input type="radio" name="sag_widgetJavascript" id="wjs_on" value="1" '. ((Configuration::get('sag_widgetJavascript')=="1") ? 'checked="checked"' : '') .'>
                <label class="t" for="wjs_on">
                Activer
                </label>
                <input type="radio" name="sag_widgetJavascript" id="wjs_off" value="" '. ((Configuration::get('sag_widgetJavascript')!="1") ? 'checked="checked"' : '') .'>
                <label class="t" for="wjs_off">
                Désactiver
                </label>
                <p class="preference_description">
                Pour choisir le widget et définir sa position,
                <a href="https://www.societe-des-avis-garantis.fr/configuration/widgets/" target="_blank">cliquez ici</a>
                </p>
            </div>

            <label>Lien de vérification </label>
            <div class="margin-form">
                <input type="radio" name="sag_footerLink" id="showFooterLink_on" value="1" '. ((Configuration::get('sag_footerLink')=="1") ? 'checked="checked"' : '') .'>
                <label class="t" for="showFooterLink_on">
                <img src="../views/img/admin/enabled.gif" alt="Oui" title="Oui">
                </label>
                <input type="radio" name="sag_footerLink" id="showFooterLink_off" value="0" '. ((Configuration::get('sag_footerLink')!="1") ? 'checked="checked"' : '') .'>
                <label class="t" for="showFooterLink_off">
                <img src="../views/img/admin/disabled.gif" alt="Non" title="Non">
                </label>
                <p class="preference_description">
                Affiche un lien de vérification dans le footer pointant vers votre certificat.
                </p>
            </div>

            <label>Forcer les données structurées </label>
            <div class="margin-form">
                <input type="radio" name="sag_showStructured" id="showStructured_on" value="1" '. ((Configuration::get('sag_showStructured')=="1") ? 'checked="checked"' : '') .'>
                <label class="t" for="showStructured_on">
                <img src="../views/img/admin/enabled.gif" alt="Oui" title="Oui">
                </label>
                <input type="radio" name="sag_showStructured" id="showStructured_off" value="0" '. ((Configuration::get('sag_showStructured')!="1") ? 'checked="checked"' : '') .'>
                <label class="t" for="showStructured_off">
                    <img src="../views/img/admin/disabled.gif" alt="Non" title="Non">
                </label>
                <p class="preference_description">
                A activer seulement si votre thème ne les implémente pas.<br><a href="https://search.google.com/structured-data/testing-tool/u/0/" target="_blank">Cliquez ici pour tester les données structurées de vos pages produit</a>
                </p>
            </div>

            <div class="margin-form">
            <input type="submit" id="_form_submit_btn" value="Enregistrer" name="mainConfig" class="button">
            </div>

            <div class="small"><sup>*</sup> Champ requis</div>
        </fieldset>
        </form>
        ';

        $firstInstallForm ='
            <fieldset id="fieldset_0">
                <legend>Première installation ?</legend>
                <label>Nom du site </label>
                <div class="margin-form">
                    <input type="text" name="api_siteName" id="api_siteName" value="' . Configuration::get('PS_SHOP_NAME') . '" class="" size="30">
                    <p class="preference_description">Apparaîtra sur votre certificat</p>
                </div>
                <input type="hidden" name="sag_accountAddress" id="sag_accountAddress" value="' . Configuration::get('PS_SHOP_ADDR1') . '">
                <input type="hidden" name="sag_accountAddress2" id="sag_accountAddress2" value="' . Configuration::get('PS_SHOP_ADDR2') . '">
                <input type="hidden" name="sag_accountCP" id="sag_accountCP" value="' . Configuration::get('PS_SHOP_CODE') . '">
                <input type="hidden" name="sag_accountCity" id="sag_accountCity" value="' . Configuration::get('PS_SHOP_CITY') . '">
                <label>Votre email </label>
                <div class="margin-form">
                    <input type="text" name="sag_accountMail" id="sag_accountMail" value="' . Configuration::get('PS_SHOP_EMAIL') . '" class="" size="30">
                    <p class="preference_description">Sera utilisé comme identifiant de votre compte Société des Avis Garantis</p>
                </div>
                <div class="margin-form">
                    <input type="checkbox" name="cgv_1" id="cgv_1" class="">
                    <label for="cgv_1" class="t"><strong>J\'accepte les <a href=https://www.societe-des-avis-garantis.fr/cgv/ target="_blank">CGV de la Société Avis Garantis</a></strong></label><br>
                </div>
                <div class="margin-form">
                    <input type="submit" id="configuration_form_submit_btn" value="Valider" name="createCertificate" class="button">
                </div>
            </fieldset>
            <br>
            <fieldset id="fieldset_1">
                <legend>Déjà inscrit ?</legend>
                <label>Clé d\'api </label>
                <div class="margin-form">
                    <input type="text" name="sag_apiKey" id="sag_apiKey" value="" class="" size="30">
                    <p class="preference_description">
                        Votre clé se trouve sur votre compte Société des avis Garantis: <a href="https://www.societe-des-avis-garantis.fr/configuration/prestashop/" target="_blank">Cliquez ici</a>
                    </p>
                </div>
                <div class="margin-form">
                    <input type="submit" id="configuration_form_submit_btn" value="Enregistrer" name="alreadyUser" class="button">
                </div>
            </fieldset>';

        if (!Configuration::get('sag_apiKey')) {
            $output .= $firstInstallForm;
        } 

        else {
            $output .= $mainForm;
        } 

        return $output;
    } 

} 

